@@ -12,6 +12,7 @@ use std::collections::{HashMap, HashSet};
 use std::path::Path;
 use std::sync::atomic::{AtomicUsize, Ordering};
 use std::{fs, io};
+use thiserror::Error;
 
 // The allowed platforms to validate the configuration
 // Note: These platforms should match the list on https://rust-lang.github.io/rustup/installation/other.html
@@ -103,27 +104,20 @@ static PLATFORMS_WINDOWS: &[&str] = &[
     "x86_64-pc-windows-gnu",
     "x86_64-pc-windows-msvc",
 ];
-
-quick_error! {
-    #[derive(Debug)]
-    pub enum SyncError {
-        Io(err: io::Error) {
-            from()
-        }
-        Download(err: DownloadError) {
-            from()
-        }
-        Parse(err: toml::de::Error) {
-            from()
-        }
-        Serialize(err: toml::ser::Error) {
-            from()
-        }
-        StripPrefix(err: std::path::StripPrefixError) {
-            from()
-        }
-        FailedDownloads(count: usize) {}
-    }
+#[derive(Error, Debug)]
+pub enum SyncError {
+    #[error("IO error: {0}")]
+    Io(#[from] io::Error),
+    #[error("Download error: {0}")]
+    Download(#[from] DownloadError),
+    #[error("TOML deserialization error: {0}")]
+    Parse(#[from] toml::de::Error),
+    #[error("TOML serialization error: {0}")]
+    Serialize(#[from] toml::ser::Error),
+    #[error("Path prefix strip error: {0}")]
+    StripPrefix(#[from] std::path::StripPrefixError),
+    #[error("Failed {count} downloads")]
+    FailedDownloads { count: usize },
 }
 
 #[derive(Deserialize, Debug)]
@@ -186,7 +180,7 @@ pub fn get_platforms(rustup: &ConfigRustup) -> Result<Platforms, MirrorError> {
         }
         None => {
             eprintln!("Info: no 'platforms_unix' specified in 'rustup' section of 'mirror.toml', mirroring all platforms.");
-            PLATFORMS_UNIX.into_iter().map(|x| x.to_string()).collect()
+            PLATFORMS_UNIX.iter().map(|x| x.to_string()).collect()
         }
     };
     let windows = match &rustup.platforms_windows {
@@ -205,11 +199,8 @@ pub fn get_platforms(rustup: &ConfigRustup) -> Result<Platforms, MirrorError> {
         }
         None => {
             eprintln!("Info: no 'platforms_windows' specified in 'rustup' section of 'mirror.toml', mirroring all platforms.");
-            PLATFORMS_WINDOWS
-                .into_iter()
-                .map(|x| x.to_string())
-                .collect()
-        },
+            PLATFORMS_WINDOWS.iter().map(|x| x.to_string()).collect()
+        }
     };
     Ok(Platforms { unix, windows })
 }
@@ -294,9 +285,21 @@ pub fn sync_rustup_init(
             let s = sender.clone();
             let rustup_version = rustup_version.clone();
             scoped.execute(move || {
-                if let Err(e) = sync_one_init(path, source, platform.as_str(), false, &rustup_version, retries, user_agent) {
+                if let Err(e) = sync_one_init(
+                    path,
+                    source,
+                    platform.as_str(),
+                    false,
+                    &rustup_version,
+                    retries,
+                    user_agent,
+                ) {
                     match e {
-                        DownloadError::NotFound(_, _, _) => {}
+                        DownloadError::NotFound {
+                            status: _,
+                            url: _,
+                            data: _,
+                        } => {}
                         _ => {
                             s.send(ProgressBarMessage::Println(format!(
                                 "Downloading {} failed: {:?}",
@@ -327,7 +330,11 @@ pub fn sync_rustup_init(
                     user_agent,
                 ) {
                     match e {
-                        DownloadError::NotFound(_, _, _) => {}
+                        DownloadError::NotFound {
+                            status: _,
+                            url: _,
+                            data: _,
+                        } => {}
                         _ => {
                             s.send(ProgressBarMessage::Println(format!(
                                 "Downloading {} failed: {:?}",
@@ -354,7 +361,7 @@ pub fn sync_rustup_init(
     if errors == 0 {
         Ok(())
     } else {
-        Err(SyncError::FailedDownloads(errors))
+        Err(SyncError::FailedDownloads { count: errors })
     }
 }
 
@@ -384,10 +391,7 @@ pub fn rustup_download_list(
                             .into_iter()
                             .flatten()
                             .map(|(url, hash)| {
-                                (
-                                    url.split("/").collect::<Vec<&str>>()[3..].join("/"),
-                                    hash,
-                                )
+                                (url.split('/').collect::<Vec<&str>>()[3..].join("/"), hash)
                             })
                             .collect()
                     })
@@ -566,6 +570,7 @@ pub fn get_rustup_version(path: &Path) -> Result<String, SyncError> {
 }
 
 /// Synchronize a rustup channel (stable, beta, or nightly).
+#[allow(clippy::too_many_arguments)]
 pub fn sync_rustup_channel(
     path: &Path,
     source: &str,
@@ -626,7 +631,7 @@ pub fn sync_rustup_channel(
         move_if_exists_with_sha256(&channel_part_path, &channel_path)?;
         Ok(())
     } else {
-        Err(SyncError::FailedDownloads(errors))
+        Err(SyncError::FailedDownloads { count: errors })
     }
 }
 
@@ -637,7 +642,6 @@ pub fn sync(
     rustup: &ConfigRustup,
     user_agent: &HeaderValue,
 ) -> Result<(), MirrorError> {
-
     let platforms = get_platforms(&rustup)?;
 
     eprintln!("{}", style("Syncing Rustup repositories...").bold());
